How to cite
===========

If you would like to acknowledge our work in a scientific paper,
please use the following citation:

.. code-block:: text

    Lackner, M., Regner, P., & Krenn, B. (2023).
    abcvoting: A Python package for approval-based multi-winner voting rules.
    Journal of Open Source Software, 8(81), 4880.

Bibtex:

.. code-block:: bibtex

    @article{joss-abcvoting,
      title={abcvoting: {A} {P}ython package for approval-based multi-winner voting rules},
      author={Martin Lackner and Peter Regner and Benjamin Krenn},
      doi = {10.21105/joss.04880},
      year = {2023},
      publisher = {The Open Journal},
      volume = {8},
      number = {81},
      pages = {4880},
      journal = {Journal of Open Source Software}
     }

(This citation contains the names of all major code contributors at the
time of publication. A full list of people
involved in the project can be found :doc:`here <acks>`.)

Alternatively, you can cite the archived code repository
at `zenodo <https://zenodo.org/record/7382436>`_.
